# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ActiveDirectory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'computer_name': 'str',
        'directory_servers': 'list[str]',
        'domain': 'str',
        'encryption_types': 'list[str]',
        'join_ou': 'str',
        'kerberos_servers': 'list[str]',
        'service_principal_names': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'computer_name': 'computer_name',
        'directory_servers': 'directory_servers',
        'domain': 'domain',
        'encryption_types': 'encryption_types',
        'join_ou': 'join_ou',
        'kerberos_servers': 'kerberos_servers',
        'service_principal_names': 'service_principal_names'
    }

    def __init__(self, id=None, name=None, computer_name=None, directory_servers=None, domain=None, encryption_types=None, join_ou=None, kerberos_servers=None, service_principal_names=None):  # noqa: E501
        """ActiveDirectory - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._computer_name = None
        self._directory_servers = None
        self._domain = None
        self._encryption_types = None
        self._join_ou = None
        self._kerberos_servers = None
        self._service_principal_names = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if computer_name is not None:
            self.computer_name = computer_name
        if directory_servers is not None:
            self.directory_servers = directory_servers
        if domain is not None:
            self.domain = domain
        if encryption_types is not None:
            self.encryption_types = encryption_types
        if join_ou is not None:
            self.join_ou = join_ou
        if kerberos_servers is not None:
            self.kerberos_servers = kerberos_servers
        if service_principal_names is not None:
            self.service_principal_names = service_principal_names

    @property
    def id(self):
        """Gets the id of this ActiveDirectory.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this ActiveDirectory.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActiveDirectory.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this ActiveDirectory.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ActiveDirectory.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this ActiveDirectory.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ActiveDirectory.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this ActiveDirectory.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def computer_name(self):
        """Gets the computer_name of this ActiveDirectory.  # noqa: E501

        The common name of the computer account to be created in the Active Directory domain. If not specified, defaults to the name of the Active Directory configuration.  # noqa: E501

        :return: The computer_name of this ActiveDirectory.  # noqa: E501
        :rtype: str
        """
        return self._computer_name

    @computer_name.setter
    def computer_name(self, computer_name):
        """Sets the computer_name of this ActiveDirectory.

        The common name of the computer account to be created in the Active Directory domain. If not specified, defaults to the name of the Active Directory configuration.  # noqa: E501

        :param computer_name: The computer_name of this ActiveDirectory.  # noqa: E501
        :type: str
        """

        self._computer_name = computer_name

    @property
    def directory_servers(self):
        """Gets the directory_servers of this ActiveDirectory.  # noqa: E501

        A list of directory servers that will be used for lookups related to user authorization. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS and will only be communicated with over the secure LDAP (LDAPS) protocol.  # noqa: E501

        :return: The directory_servers of this ActiveDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._directory_servers

    @directory_servers.setter
    def directory_servers(self, directory_servers):
        """Sets the directory_servers of this ActiveDirectory.

        A list of directory servers that will be used for lookups related to user authorization. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS and will only be communicated with over the secure LDAP (LDAPS) protocol.  # noqa: E501

        :param directory_servers: The directory_servers of this ActiveDirectory.  # noqa: E501
        :type: list[str]
        """

        self._directory_servers = directory_servers

    @property
    def domain(self):
        """Gets the domain of this ActiveDirectory.  # noqa: E501

        The Active Directory domain to join.  # noqa: E501

        :return: The domain of this ActiveDirectory.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ActiveDirectory.

        The Active Directory domain to join.  # noqa: E501

        :param domain: The domain of this ActiveDirectory.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def encryption_types(self):
        """Gets the encryption_types of this ActiveDirectory.  # noqa: E501

        The encryption types that are supported for use by clients for Kerberos authentication.  # noqa: E501

        :return: The encryption_types of this ActiveDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._encryption_types

    @encryption_types.setter
    def encryption_types(self, encryption_types):
        """Sets the encryption_types of this ActiveDirectory.

        The encryption types that are supported for use by clients for Kerberos authentication.  # noqa: E501

        :param encryption_types: The encryption_types of this ActiveDirectory.  # noqa: E501
        :type: list[str]
        """

        self._encryption_types = encryption_types

    @property
    def join_ou(self):
        """Gets the join_ou of this ActiveDirectory.  # noqa: E501

        The relative distinguished name of the organizational unit in which the computer account was created when joining the domain.  # noqa: E501

        :return: The join_ou of this ActiveDirectory.  # noqa: E501
        :rtype: str
        """
        return self._join_ou

    @join_ou.setter
    def join_ou(self, join_ou):
        """Sets the join_ou of this ActiveDirectory.

        The relative distinguished name of the organizational unit in which the computer account was created when joining the domain.  # noqa: E501

        :param join_ou: The join_ou of this ActiveDirectory.  # noqa: E501
        :type: str
        """

        self._join_ou = join_ou

    @property
    def kerberos_servers(self):
        """Gets the kerberos_servers of this ActiveDirectory.  # noqa: E501

        A list of key distribution servers to use for Kerberos protocol. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS.  # noqa: E501

        :return: The kerberos_servers of this ActiveDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._kerberos_servers

    @kerberos_servers.setter
    def kerberos_servers(self, kerberos_servers):
        """Sets the kerberos_servers of this ActiveDirectory.

        A list of key distribution servers to use for Kerberos protocol. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS.  # noqa: E501

        :param kerberos_servers: The kerberos_servers of this ActiveDirectory.  # noqa: E501
        :type: list[str]
        """

        self._kerberos_servers = kerberos_servers

    @property
    def service_principal_names(self):
        """Gets the service_principal_names of this ActiveDirectory.  # noqa: E501

        A list of service principal names registered for the machine account, which can be used for the creation of keys for Kerberos authentication.  # noqa: E501

        :return: The service_principal_names of this ActiveDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._service_principal_names

    @service_principal_names.setter
    def service_principal_names(self, service_principal_names):
        """Sets the service_principal_names of this ActiveDirectory.

        A list of service principal names registered for the machine account, which can be used for the creation of keys for Kerberos authentication.  # noqa: E501

        :param service_principal_names: The service_principal_names of this ActiveDirectory.  # noqa: E501
        :type: list[str]
        """

        self._service_principal_names = service_principal_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActiveDirectory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActiveDirectory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot10
from purity_fb_1dot10.rest import ApiException
from purity_fb_1dot10.apis.syslog_api import SyslogApi


class TestSyslogApi(unittest.TestCase):
    """ SyslogApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot10.apis.syslog_api.SyslogApi()

    def tearDown(self):
        pass

    def test_create_syslog_servers(self):
        """
        Test case for create_syslog_servers

        
        """
        pass

    def test_delete_syslog_servers(self):
        """
        Test case for delete_syslog_servers

        
        """
        pass

    def test_list_syslog_servers(self):
        """
        Test case for list_syslog_servers

        
        """
        pass

    def test_list_syslog_settings(self):
        """
        Test case for list_syslog_settings

        
        """
        pass

    def test_test_syslog_config(self):
        """
        Test case for test_syslog_config

        
        """
        pass

    def test_update_syslog_servers(self):
        """
        Test case for update_syslog_servers

        
        """
        pass

    def test_update_syslog_settings(self):
        """
        Test case for update_syslog_settings

        
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot9
from purity_fb_1dot9.rest import ApiException
from purity_fb_1dot9.models.array_connection_path import ArrayConnectionPath


class TestArrayConnectionPath(unittest.TestCase):
    """ ArrayConnectionPath unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testArrayConnectionPath(self):
        """
        Test ArrayConnectionPath
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = purity_fb_1dot9.models.array_connection_path.ArrayConnectionPath()
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ActiveDirectoryPost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'computer_name': 'str',
        'directory_servers': 'list[str]',
        'domain': 'str',
        'encryption_types': 'list[str]',
        'fqdns': 'list[str]',
        'join_ou': 'str',
        'kerberos_servers': 'list[str]',
        'password': 'str',
        'service_principal_names': 'list[str]',
        'user': 'str'
    }

    attribute_map = {
        'computer_name': 'computer_name',
        'directory_servers': 'directory_servers',
        'domain': 'domain',
        'encryption_types': 'encryption_types',
        'fqdns': 'fqdns',
        'join_ou': 'join_ou',
        'kerberos_servers': 'kerberos_servers',
        'password': 'password',
        'service_principal_names': 'service_principal_names',
        'user': 'user'
    }

    def __init__(self, computer_name=None, directory_servers=None, domain=None, encryption_types=None, fqdns=None, join_ou=None, kerberos_servers=None, password=None, service_principal_names=None, user=None):  # noqa: E501
        """ActiveDirectoryPost - a model defined in Swagger"""  # noqa: E501

        self._computer_name = None
        self._directory_servers = None
        self._domain = None
        self._encryption_types = None
        self._fqdns = None
        self._join_ou = None
        self._kerberos_servers = None
        self._password = None
        self._service_principal_names = None
        self._user = None
        self.discriminator = None

        if computer_name is not None:
            self.computer_name = computer_name
        if directory_servers is not None:
            self.directory_servers = directory_servers
        self.domain = domain
        if encryption_types is not None:
            self.encryption_types = encryption_types
        if fqdns is not None:
            self.fqdns = fqdns
        if join_ou is not None:
            self.join_ou = join_ou
        if kerberos_servers is not None:
            self.kerberos_servers = kerberos_servers
        self.password = password
        if service_principal_names is not None:
            self.service_principal_names = service_principal_names
        self.user = user

    @property
    def computer_name(self):
        """Gets the computer_name of this ActiveDirectoryPost.  # noqa: E501

        The common name of the computer account to be created in the Active Directory domain. If not specified, defaults to the name of the Active Directory configuration.  # noqa: E501

        :return: The computer_name of this ActiveDirectoryPost.  # noqa: E501
        :rtype: str
        """
        return self._computer_name

    @computer_name.setter
    def computer_name(self, computer_name):
        """Sets the computer_name of this ActiveDirectoryPost.

        The common name of the computer account to be created in the Active Directory domain. If not specified, defaults to the name of the Active Directory configuration.  # noqa: E501

        :param computer_name: The computer_name of this ActiveDirectoryPost.  # noqa: E501
        :type: str
        """

        self._computer_name = computer_name

    @property
    def directory_servers(self):
        """Gets the directory_servers of this ActiveDirectoryPost.  # noqa: E501

        A list of directory servers that will be used for lookups related to user authorization. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS and will only be communicated with over the secure LDAP (LDAPS) protocol. If not specified, servers are resolved for the domain in DNS. The specified list can have a maximum length of 5.  # noqa: E501

        :return: The directory_servers of this ActiveDirectoryPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._directory_servers

    @directory_servers.setter
    def directory_servers(self, directory_servers):
        """Sets the directory_servers of this ActiveDirectoryPost.

        A list of directory servers that will be used for lookups related to user authorization. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS and will only be communicated with over the secure LDAP (LDAPS) protocol. If not specified, servers are resolved for the domain in DNS. The specified list can have a maximum length of 5.  # noqa: E501

        :param directory_servers: The directory_servers of this ActiveDirectoryPost.  # noqa: E501
        :type: list[str]
        """

        self._directory_servers = directory_servers

    @property
    def domain(self):
        """Gets the domain of this ActiveDirectoryPost.  # noqa: E501

        The Active Directory domain to join.  # noqa: E501

        :return: The domain of this ActiveDirectoryPost.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ActiveDirectoryPost.

        The Active Directory domain to join.  # noqa: E501

        :param domain: The domain of this ActiveDirectoryPost.  # noqa: E501
        :type: str
        """
        if domain is None:
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def encryption_types(self):
        """Gets the encryption_types of this ActiveDirectoryPost.  # noqa: E501

        The encryption types that will be supported for use by clients for Kerberos authentication. Defaults to `aes256-cts-hmac-sha1-96`. Valid values include `aes256-cts-hmac-sha1-96`, `aes128-cts-hmac-sha1-96`, and `arcfour-hmac`. Cannot be provided if using an existing machine account.  # noqa: E501

        :return: The encryption_types of this ActiveDirectoryPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._encryption_types

    @encryption_types.setter
    def encryption_types(self, encryption_types):
        """Sets the encryption_types of this ActiveDirectoryPost.

        The encryption types that will be supported for use by clients for Kerberos authentication. Defaults to `aes256-cts-hmac-sha1-96`. Valid values include `aes256-cts-hmac-sha1-96`, `aes128-cts-hmac-sha1-96`, and `arcfour-hmac`. Cannot be provided if using an existing machine account.  # noqa: E501

        :param encryption_types: The encryption_types of this ActiveDirectoryPost.  # noqa: E501
        :type: list[str]
        """

        self._encryption_types = encryption_types

    @property
    def fqdns(self):
        """Gets the fqdns of this ActiveDirectoryPost.  # noqa: E501

        A list of fully qualified domain names to use to register service principal names for the machine account. If specified, every service principal that is supported by the array will be registered for each fully qualified domain name specified. If neither `fqdns` nor `service_principal_names` is specified, the default `service_principal_names` are constructed using the `computer_name` and `domain` fields. Cannot be provided in combination with `service_principal_names`. Cannot be provided if using an existing machine account.  # noqa: E501

        :return: The fqdns of this ActiveDirectoryPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._fqdns

    @fqdns.setter
    def fqdns(self, fqdns):
        """Sets the fqdns of this ActiveDirectoryPost.

        A list of fully qualified domain names to use to register service principal names for the machine account. If specified, every service principal that is supported by the array will be registered for each fully qualified domain name specified. If neither `fqdns` nor `service_principal_names` is specified, the default `service_principal_names` are constructed using the `computer_name` and `domain` fields. Cannot be provided in combination with `service_principal_names`. Cannot be provided if using an existing machine account.  # noqa: E501

        :param fqdns: The fqdns of this ActiveDirectoryPost.  # noqa: E501
        :type: list[str]
        """

        self._fqdns = fqdns

    @property
    def join_ou(self):
        """Gets the join_ou of this ActiveDirectoryPost.  # noqa: E501

        The relative distinguished name of the organizational unit in which the computer account should be created when joining the domain. Cannot be provided if using an existing machine account. If not specified, defaults to `CN=Computers`.  # noqa: E501

        :return: The join_ou of this ActiveDirectoryPost.  # noqa: E501
        :rtype: str
        """
        return self._join_ou

    @join_ou.setter
    def join_ou(self, join_ou):
        """Sets the join_ou of this ActiveDirectoryPost.

        The relative distinguished name of the organizational unit in which the computer account should be created when joining the domain. Cannot be provided if using an existing machine account. If not specified, defaults to `CN=Computers`.  # noqa: E501

        :param join_ou: The join_ou of this ActiveDirectoryPost.  # noqa: E501
        :type: str
        """

        self._join_ou = join_ou

    @property
    def kerberos_servers(self):
        """Gets the kerberos_servers of this ActiveDirectoryPost.  # noqa: E501

        A list of key distribution servers to use for Kerberos protocol. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS. If not specified, servers are resolved for the domain in DNS. The specified list can have a maximum length of 5.  # noqa: E501

        :return: The kerberos_servers of this ActiveDirectoryPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._kerberos_servers

    @kerberos_servers.setter
    def kerberos_servers(self, kerberos_servers):
        """Sets the kerberos_servers of this ActiveDirectoryPost.

        A list of key distribution servers to use for Kerberos protocol. Accepted server formats are IP address and DNS name. All specified servers must be registered to the domain appropriately in the array's configured DNS. If not specified, servers are resolved for the domain in DNS. The specified list can have a maximum length of 5.  # noqa: E501

        :param kerberos_servers: The kerberos_servers of this ActiveDirectoryPost.  # noqa: E501
        :type: list[str]
        """

        self._kerberos_servers = kerberos_servers

    @property
    def password(self):
        """Gets the password of this ActiveDirectoryPost.  # noqa: E501

        The login password of the user with privileges to create the computer account in the domain. If using an existing computer account, the user must have privileges to read attributes from the computer account and reset the password on that account. This is not persisted on the array.  # noqa: E501

        :return: The password of this ActiveDirectoryPost.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this ActiveDirectoryPost.

        The login password of the user with privileges to create the computer account in the domain. If using an existing computer account, the user must have privileges to read attributes from the computer account and reset the password on that account. This is not persisted on the array.  # noqa: E501

        :param password: The password of this ActiveDirectoryPost.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def service_principal_names(self):
        """Gets the service_principal_names of this ActiveDirectoryPost.  # noqa: E501

        A list of service principal names to register for the machine account, which can be used for the creation of keys for Kerberos authentication. If neither `service_principal_names` nor `fqdns` is specified, the default `service_principal_names` are constructed using the `computer_name` and `domain` fields. Cannot be provided in combination with `fqdns`. Cannot be provided if using an existing machine account.  # noqa: E501

        :return: The service_principal_names of this ActiveDirectoryPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._service_principal_names

    @service_principal_names.setter
    def service_principal_names(self, service_principal_names):
        """Sets the service_principal_names of this ActiveDirectoryPost.

        A list of service principal names to register for the machine account, which can be used for the creation of keys for Kerberos authentication. If neither `service_principal_names` nor `fqdns` is specified, the default `service_principal_names` are constructed using the `computer_name` and `domain` fields. Cannot be provided in combination with `fqdns`. Cannot be provided if using an existing machine account.  # noqa: E501

        :param service_principal_names: The service_principal_names of this ActiveDirectoryPost.  # noqa: E501
        :type: list[str]
        """

        self._service_principal_names = service_principal_names

    @property
    def user(self):
        """Gets the user of this ActiveDirectoryPost.  # noqa: E501

        The login name of the user with privileges to create the computer account in the domain. If using an existing computer account, the user must have privileges to read attributes from the computer account and reset the password on that account. This is not persisted on the array.  # noqa: E501

        :return: The user of this ActiveDirectoryPost.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ActiveDirectoryPost.

        The login name of the user with privileges to create the computer account in the domain. If using an existing computer account, the user must have privileges to read attributes from the computer account and reset the password on that account. This is not persisted on the array.  # noqa: E501

        :param user: The user of this ActiveDirectoryPost.  # noqa: E501
        :type: str
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActiveDirectoryPost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActiveDirectoryPost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot12
from purity_fb_1dot12.rest import ApiException
from purity_fb_1dot12.apis.object_store_access_policies_api import ObjectStoreAccessPoliciesApi


class TestObjectStoreAccessPoliciesApi(unittest.TestCase):
    """ ObjectStoreAccessPoliciesApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot12.apis.object_store_access_policies_api.ObjectStoreAccessPoliciesApi()

    def tearDown(self):
        pass

    def test_add_object_store_access_policies_object_store_users(self):
        """
        Test case for add_object_store_access_policies_object_store_users

        
        """
        pass

    def test_list_object_store_access_policies(self):
        """
        Test case for list_object_store_access_policies

        
        """
        pass

    def test_list_object_store_access_policies_object_store_users(self):
        """
        Test case for list_object_store_access_policies_object_store_users

        
        """
        pass

    def test_remove_object_store_access_policies_object_store_users(self):
        """
        Test case for remove_object_store_access_policies_object_store_users

        
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BucketS3Performance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'others_per_sec': 'int',
        'read_buckets_per_sec': 'int',
        'read_objects_per_sec': 'int',
        'write_buckets_per_sec': 'int',
        'write_objects_per_sec': 'int',
        'time': 'int',
        'usec_per_other_op': 'int',
        'usec_per_read_bucket_op': 'int',
        'usec_per_read_object_op': 'int',
        'usec_per_write_bucket_op': 'int',
        'usec_per_write_object_op': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'others_per_sec': 'others_per_sec',
        'read_buckets_per_sec': 'read_buckets_per_sec',
        'read_objects_per_sec': 'read_objects_per_sec',
        'write_buckets_per_sec': 'write_buckets_per_sec',
        'write_objects_per_sec': 'write_objects_per_sec',
        'time': 'time',
        'usec_per_other_op': 'usec_per_other_op',
        'usec_per_read_bucket_op': 'usec_per_read_bucket_op',
        'usec_per_read_object_op': 'usec_per_read_object_op',
        'usec_per_write_bucket_op': 'usec_per_write_bucket_op',
        'usec_per_write_object_op': 'usec_per_write_object_op'
    }

    def __init__(self, id=None, name=None, others_per_sec=None, read_buckets_per_sec=None, read_objects_per_sec=None, write_buckets_per_sec=None, write_objects_per_sec=None, time=None, usec_per_other_op=None, usec_per_read_bucket_op=None, usec_per_read_object_op=None, usec_per_write_bucket_op=None, usec_per_write_object_op=None):  # noqa: E501
        """BucketS3Performance - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._others_per_sec = None
        self._read_buckets_per_sec = None
        self._read_objects_per_sec = None
        self._write_buckets_per_sec = None
        self._write_objects_per_sec = None
        self._time = None
        self._usec_per_other_op = None
        self._usec_per_read_bucket_op = None
        self._usec_per_read_object_op = None
        self._usec_per_write_bucket_op = None
        self._usec_per_write_object_op = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if others_per_sec is not None:
            self.others_per_sec = others_per_sec
        if read_buckets_per_sec is not None:
            self.read_buckets_per_sec = read_buckets_per_sec
        if read_objects_per_sec is not None:
            self.read_objects_per_sec = read_objects_per_sec
        if write_buckets_per_sec is not None:
            self.write_buckets_per_sec = write_buckets_per_sec
        if write_objects_per_sec is not None:
            self.write_objects_per_sec = write_objects_per_sec
        if time is not None:
            self.time = time
        if usec_per_other_op is not None:
            self.usec_per_other_op = usec_per_other_op
        if usec_per_read_bucket_op is not None:
            self.usec_per_read_bucket_op = usec_per_read_bucket_op
        if usec_per_read_object_op is not None:
            self.usec_per_read_object_op = usec_per_read_object_op
        if usec_per_write_bucket_op is not None:
            self.usec_per_write_bucket_op = usec_per_write_bucket_op
        if usec_per_write_object_op is not None:
            self.usec_per_write_object_op = usec_per_write_object_op

    @property
    def id(self):
        """Gets the id of this BucketS3Performance.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this BucketS3Performance.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BucketS3Performance.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this BucketS3Performance.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this BucketS3Performance.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this BucketS3Performance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BucketS3Performance.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this BucketS3Performance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def others_per_sec(self):
        """Gets the others_per_sec of this BucketS3Performance.  # noqa: E501

        Other operations processed per second.  # noqa: E501

        :return: The others_per_sec of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._others_per_sec

    @others_per_sec.setter
    def others_per_sec(self, others_per_sec):
        """Sets the others_per_sec of this BucketS3Performance.

        Other operations processed per second.  # noqa: E501

        :param others_per_sec: The others_per_sec of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if others_per_sec is not None and others_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `others_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._others_per_sec = others_per_sec

    @property
    def read_buckets_per_sec(self):
        """Gets the read_buckets_per_sec of this BucketS3Performance.  # noqa: E501

        Read buckets requests processed per second.  # noqa: E501

        :return: The read_buckets_per_sec of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._read_buckets_per_sec

    @read_buckets_per_sec.setter
    def read_buckets_per_sec(self, read_buckets_per_sec):
        """Sets the read_buckets_per_sec of this BucketS3Performance.

        Read buckets requests processed per second.  # noqa: E501

        :param read_buckets_per_sec: The read_buckets_per_sec of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if read_buckets_per_sec is not None and read_buckets_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `read_buckets_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._read_buckets_per_sec = read_buckets_per_sec

    @property
    def read_objects_per_sec(self):
        """Gets the read_objects_per_sec of this BucketS3Performance.  # noqa: E501

        Read object requests processed per second.  # noqa: E501

        :return: The read_objects_per_sec of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._read_objects_per_sec

    @read_objects_per_sec.setter
    def read_objects_per_sec(self, read_objects_per_sec):
        """Sets the read_objects_per_sec of this BucketS3Performance.

        Read object requests processed per second.  # noqa: E501

        :param read_objects_per_sec: The read_objects_per_sec of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if read_objects_per_sec is not None and read_objects_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `read_objects_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._read_objects_per_sec = read_objects_per_sec

    @property
    def write_buckets_per_sec(self):
        """Gets the write_buckets_per_sec of this BucketS3Performance.  # noqa: E501

        Write buckets requests processed per second.  # noqa: E501

        :return: The write_buckets_per_sec of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._write_buckets_per_sec

    @write_buckets_per_sec.setter
    def write_buckets_per_sec(self, write_buckets_per_sec):
        """Sets the write_buckets_per_sec of this BucketS3Performance.

        Write buckets requests processed per second.  # noqa: E501

        :param write_buckets_per_sec: The write_buckets_per_sec of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if write_buckets_per_sec is not None and write_buckets_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `write_buckets_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._write_buckets_per_sec = write_buckets_per_sec

    @property
    def write_objects_per_sec(self):
        """Gets the write_objects_per_sec of this BucketS3Performance.  # noqa: E501

        Write object requests processed per second.  # noqa: E501

        :return: The write_objects_per_sec of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._write_objects_per_sec

    @write_objects_per_sec.setter
    def write_objects_per_sec(self, write_objects_per_sec):
        """Sets the write_objects_per_sec of this BucketS3Performance.

        Write object requests processed per second.  # noqa: E501

        :param write_objects_per_sec: The write_objects_per_sec of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if write_objects_per_sec is not None and write_objects_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `write_objects_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._write_objects_per_sec = write_objects_per_sec

    @property
    def time(self):
        """Gets the time of this BucketS3Performance.  # noqa: E501

        Sample time in milliseconds since UNIX epoch.  # noqa: E501

        :return: The time of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this BucketS3Performance.

        Sample time in milliseconds since UNIX epoch.  # noqa: E501

        :param time: The time of this BucketS3Performance.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def usec_per_other_op(self):
        """Gets the usec_per_other_op of this BucketS3Performance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process other operations.  # noqa: E501

        :return: The usec_per_other_op of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_other_op

    @usec_per_other_op.setter
    def usec_per_other_op(self, usec_per_other_op):
        """Sets the usec_per_other_op of this BucketS3Performance.

        Average time, measured in microseconds, it takes the array to process other operations.  # noqa: E501

        :param usec_per_other_op: The usec_per_other_op of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if usec_per_other_op is not None and usec_per_other_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_other_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_other_op = usec_per_other_op

    @property
    def usec_per_read_bucket_op(self):
        """Gets the usec_per_read_bucket_op of this BucketS3Performance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a read bucket request.  # noqa: E501

        :return: The usec_per_read_bucket_op of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_bucket_op

    @usec_per_read_bucket_op.setter
    def usec_per_read_bucket_op(self, usec_per_read_bucket_op):
        """Sets the usec_per_read_bucket_op of this BucketS3Performance.

        Average time, measured in microseconds, it takes the array to process a read bucket request.  # noqa: E501

        :param usec_per_read_bucket_op: The usec_per_read_bucket_op of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if usec_per_read_bucket_op is not None and usec_per_read_bucket_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_bucket_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_bucket_op = usec_per_read_bucket_op

    @property
    def usec_per_read_object_op(self):
        """Gets the usec_per_read_object_op of this BucketS3Performance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a read object request.  # noqa: E501

        :return: The usec_per_read_object_op of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_object_op

    @usec_per_read_object_op.setter
    def usec_per_read_object_op(self, usec_per_read_object_op):
        """Sets the usec_per_read_object_op of this BucketS3Performance.

        Average time, measured in microseconds, it takes the array to process a read object request.  # noqa: E501

        :param usec_per_read_object_op: The usec_per_read_object_op of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if usec_per_read_object_op is not None and usec_per_read_object_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_object_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_object_op = usec_per_read_object_op

    @property
    def usec_per_write_bucket_op(self):
        """Gets the usec_per_write_bucket_op of this BucketS3Performance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a write bucket request.  # noqa: E501

        :return: The usec_per_write_bucket_op of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_bucket_op

    @usec_per_write_bucket_op.setter
    def usec_per_write_bucket_op(self, usec_per_write_bucket_op):
        """Sets the usec_per_write_bucket_op of this BucketS3Performance.

        Average time, measured in microseconds, it takes the array to process a write bucket request.  # noqa: E501

        :param usec_per_write_bucket_op: The usec_per_write_bucket_op of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if usec_per_write_bucket_op is not None and usec_per_write_bucket_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_bucket_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_bucket_op = usec_per_write_bucket_op

    @property
    def usec_per_write_object_op(self):
        """Gets the usec_per_write_object_op of this BucketS3Performance.  # noqa: E501

        Average time, measured in microseconds, it takes the array to process a write object request.  # noqa: E501

        :return: The usec_per_write_object_op of this BucketS3Performance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_object_op

    @usec_per_write_object_op.setter
    def usec_per_write_object_op(self, usec_per_write_object_op):
        """Sets the usec_per_write_object_op of this BucketS3Performance.

        Average time, measured in microseconds, it takes the array to process a write object request.  # noqa: E501

        :param usec_per_write_object_op: The usec_per_write_object_op of this BucketS3Performance.  # noqa: E501
        :type: int
        """
        if usec_per_write_object_op is not None and usec_per_write_object_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_object_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_object_op = usec_per_write_object_op

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BucketS3Performance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BucketS3Performance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import ssl
import urllib3
import inspect
import re
from distutils.version import LooseVersion

from .api_client.api_client import ApiClient
from .api_client.version_api import VersionApi
from .api_client import rest

from . import purity_fb_1dot0
from . import purity_fb_1dot1
from . import purity_fb_1dot2
from . import purity_fb_1dot3
from . import purity_fb_1dot4
from . import purity_fb_1dot5
from . import purity_fb_1dot6
from . import purity_fb_1dot7
from . import purity_fb_1dot8
from . import purity_fb_1dot8dot1
from . import purity_fb_1dot9
from . import purity_fb_1dot10
from . import purity_fb_1dot11
from . import purity_fb_1dot12

SUPPORTED_VERSIONS = ['1.0', '1.1', '1.2', '1.3', '1.4', '1.5', '1.6', '1.7', '1.8', '1.8.1', '1.9', '1.10', '1.11', '1.12']

version_module_dict = {
    '1.0': purity_fb_1dot0,
    '1.1': purity_fb_1dot1,
    '1.2': purity_fb_1dot2,
    '1.3': purity_fb_1dot3,
    '1.4': purity_fb_1dot4,
    '1.5': purity_fb_1dot5,
    '1.6': purity_fb_1dot6,
    '1.7': purity_fb_1dot7,
    '1.8': purity_fb_1dot8,
    '1.8.1': purity_fb_1dot8dot1,
    '1.9': purity_fb_1dot9,
    '1.10': purity_fb_1dot10,
    '1.11': purity_fb_1dot11,
    '1.12': purity_fb_1dot12,
}


class PurityFb:
    DEFAULT_READ_TIMEOUT = 30.0
    DEFAULT_CONN_TIMEOUT = 10.0
    DEFAULT_RETRIES = 5

    def __init__(self, host, version=None, api_token=None, ca_certs_file_path=None):
        self._api_client = ApiClient(host='https://{}/api'.format(host))
        self.request_timeout = urllib3.Timeout(
            connect=PurityFb.DEFAULT_CONN_TIMEOUT,
            read=PurityFb.DEFAULT_READ_TIMEOUT)
        self.retries = urllib3.Retry(total=PurityFb.DEFAULT_RETRIES)

        if not ca_certs_file_path:
            self.disable_verify_ssl()
        else:
            self.configure_ca_certificate_file(ca_certs_file_path)
            self.enable_verify_ssl()

        self.api_version = VersionApi(self._api_client)
        if version:
            self._version = self._check_rest_version(version)
        else:
            self._version = self._choose_rest_version()

        # Take the latest REST API version which is the client version as user agent version
        self._api_client.user_agent = 'Purity_FB_Python_Client/' + str(SUPPORTED_VERSIONS[-1])

        purity_fb_version_module = version_module_dict.get(str(self._version))
        # This setting is needed for the _api_client to be able to deserialize response
        self._api_client.set_models(purity_fb_version_module.models)

        # Expose specific version's object model to user so user can use accurate model version
        self.models = purity_fb_version_module.models

        clsmembers = inspect.getmembers(purity_fb_version_module, inspect.isclass)
        for member in clsmembers:
            if len(member) != 2:
                continue
            if member[0].endswith("Api"):
                self.__dict__[self.camel_to_snake(member[0])[:-4]] = member[1](self._api_client)

        if api_token:
            self.login(api_token)

    def _class_name(self, api, version):
        return api + str(version).replace('.', 'dot') + 'Api'

    def list_versions(self):
        try:
            return self.api_version.list_versions().versions
        except rest.ApiException:
            return ['1.0']

    def login(self, api_token):
        try:
            self.logout()
        except rest.ApiException:
            pass
        res = self.authentication.login_with_http_info(api_token=api_token)
        self._api_client.default_headers['x-auth-token'] = res[2]['x-auth-token']
        return res[1]

    def logout(self):
        return self.authentication.logout_with_http_info()[1]

    def allow_verify_ssl(self, ca_certs_file_path=None):
        """ Change our certificate requirements so that a certificate is validated if provided,
        but a certificate is not required.
        Optionally, if a CA certificate(s) file path is provided, configure the client to use
        that CA certificate file.
        """
        if ca_certs_file_path:
            self.configure_ca_certificate_file(ca_certs_file_path)
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_OPTIONAL

    def disable_verify_ssl(self):
        """ Change our certificate requirements so that a certificate is not validated. """
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_NONE

    def enable_verify_ssl(self, ca_certs_file_path=None):
        """ Change our certificate requirements so that a certificate is required and validated.
        Optionally, if a CA certificate(s) file path is provided, configure the client to use
        that CA certificate file.
        """
        if ca_certs_file_path:
            self.configure_ca_certificate_file(ca_certs_file_path)
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_REQUIRED

    def configure_ca_certificate_file(self, ca_certs_file_path):
        """"
        :param ca_certs_file_path: The path to the CA certificate(s) file to use.
        :return:
        """
        self._api_client.rest_client.pool_manager.connection_pool_kw['ca_certs'] = ca_certs_file_path

    @property
    def request_timeout(self):
        return self._api_client.rest_client.pool_manager.connection_pool_kw['timeout']

    @request_timeout.setter
    def request_timeout(self, value):
        self._api_client.rest_client.pool_manager.connection_pool_kw['timeout'] = value

    @property
    def request_retry(self):
        return self._api_client.rest_client.pool_manager.connection_pool_kw['retries']

    @request_retry.setter
    def request_retry(self, value):
        self._api_client.rest_client.pool_manager.connection_pool_kw['retries'] = value

    @staticmethod
    def camel_to_snake(name):
        s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
        return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()

    @staticmethod
    def version_to_module(version):
        if version not in SUPPORTED_VERSIONS:
            msg = "Library is incompatible with REST API version {0}"
            raise ValueError(msg.format(version))

        return "purity_fb_"

    def _check_rest_version(self, version):
        """Validate a REST API version is supported by the library and target array."""
        version = str(version)

        if version not in SUPPORTED_VERSIONS:
            msg = "Library is incompatible with REST API version {0}"
            raise ValueError(msg.format(version))

        array_rest_versions = self.list_versions()
        if version not in array_rest_versions:
            msg = "Array is incompatible with REST API version {0}"
            raise ValueError(msg.format(version))

        return LooseVersion(version)

    def _choose_rest_version(self):
        """Return the newest REST API version supported by target array."""
        versions = self.list_versions()
        versions = [LooseVersion(x) for x in versions if x in SUPPORTED_VERSIONS]
        if versions:
            return max(versions)
        else:
            raise RuntimeError(
                "Library is incompatible with all REST API versions supported"
                "by the target array.")



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SnmpV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_passphrase': 'str',
        'auth_protocol': 'str',
        'privacy_passphrase': 'str',
        'privacy_protocol': 'str',
        'user': 'str'
    }

    attribute_map = {
        'auth_passphrase': 'auth_passphrase',
        'auth_protocol': 'auth_protocol',
        'privacy_passphrase': 'privacy_passphrase',
        'privacy_protocol': 'privacy_protocol',
        'user': 'user'
    }

    def __init__(self, auth_passphrase=None, auth_protocol=None, privacy_passphrase=None, privacy_protocol=None, user=None):  # noqa: E501
        """SnmpV3 - a model defined in Swagger"""  # noqa: E501

        self._auth_passphrase = None
        self._auth_protocol = None
        self._privacy_passphrase = None
        self._privacy_protocol = None
        self._user = None
        self.discriminator = None

        if auth_passphrase is not None:
            self.auth_passphrase = auth_passphrase
        if auth_protocol is not None:
            self.auth_protocol = auth_protocol
        if privacy_passphrase is not None:
            self.privacy_passphrase = privacy_passphrase
        if privacy_protocol is not None:
            self.privacy_protocol = privacy_protocol
        if user is not None:
            self.user = user

    @property
    def auth_passphrase(self):
        """Gets the auth_passphrase of this SnmpV3.  # noqa: E501

        Passphrase used by Purity to authenticate the array with the specified managers.  # noqa: E501

        :return: The auth_passphrase of this SnmpV3.  # noqa: E501
        :rtype: str
        """
        return self._auth_passphrase

    @auth_passphrase.setter
    def auth_passphrase(self, auth_passphrase):
        """Sets the auth_passphrase of this SnmpV3.

        Passphrase used by Purity to authenticate the array with the specified managers.  # noqa: E501

        :param auth_passphrase: The auth_passphrase of this SnmpV3.  # noqa: E501
        :type: str
        """
        if auth_passphrase is not None and len(auth_passphrase) > 32:
            raise ValueError("Invalid value for `auth_passphrase`, length must be less than or equal to `32`")  # noqa: E501

        self._auth_passphrase = auth_passphrase

    @property
    def auth_protocol(self):
        """Gets the auth_protocol of this SnmpV3.  # noqa: E501

        Hash algorithm used to validate the authentication passphrase. Valid values are `MD5` and `SHA`.  # noqa: E501

        :return: The auth_protocol of this SnmpV3.  # noqa: E501
        :rtype: str
        """
        return self._auth_protocol

    @auth_protocol.setter
    def auth_protocol(self, auth_protocol):
        """Sets the auth_protocol of this SnmpV3.

        Hash algorithm used to validate the authentication passphrase. Valid values are `MD5` and `SHA`.  # noqa: E501

        :param auth_protocol: The auth_protocol of this SnmpV3.  # noqa: E501
        :type: str
        """

        self._auth_protocol = auth_protocol

    @property
    def privacy_passphrase(self):
        """Gets the privacy_passphrase of this SnmpV3.  # noqa: E501

        Passphrase used to encrypt SNMP messages. A passphrase must be at least 8 characters in length, and may be at most 63 characters in length.  # noqa: E501

        :return: The privacy_passphrase of this SnmpV3.  # noqa: E501
        :rtype: str
        """
        return self._privacy_passphrase

    @privacy_passphrase.setter
    def privacy_passphrase(self, privacy_passphrase):
        """Sets the privacy_passphrase of this SnmpV3.

        Passphrase used to encrypt SNMP messages. A passphrase must be at least 8 characters in length, and may be at most 63 characters in length.  # noqa: E501

        :param privacy_passphrase: The privacy_passphrase of this SnmpV3.  # noqa: E501
        :type: str
        """

        self._privacy_passphrase = privacy_passphrase

    @property
    def privacy_protocol(self):
        """Gets the privacy_protocol of this SnmpV3.  # noqa: E501

        Encryption protocol for SNMP messages. Valid values are `AES` and `DES`.  # noqa: E501

        :return: The privacy_protocol of this SnmpV3.  # noqa: E501
        :rtype: str
        """
        return self._privacy_protocol

    @privacy_protocol.setter
    def privacy_protocol(self, privacy_protocol):
        """Sets the privacy_protocol of this SnmpV3.

        Encryption protocol for SNMP messages. Valid values are `AES` and `DES`.  # noqa: E501

        :param privacy_protocol: The privacy_protocol of this SnmpV3.  # noqa: E501
        :type: str
        """

        self._privacy_protocol = privacy_protocol

    @property
    def user(self):
        """Gets the user of this SnmpV3.  # noqa: E501

        User ID recognized by the specified SNMP managers which Purity is to use in communications with them.  # noqa: E501

        :return: The user of this SnmpV3.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this SnmpV3.

        User ID recognized by the specified SNMP managers which Purity is to use in communications with them.  # noqa: E501

        :param user: The user of this SnmpV3.  # noqa: E501
        :type: str
        """

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnmpV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnmpV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.2 Python SDK

    Pure Storage FlashBlade REST 1.2 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.2
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Admin(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'api_token': 'AdminApiToken',
        'create_api_token': 'bool',
        'api_token_timeout': 'int',
        'delete_api_token': 'bool',
        'old_password': 'str',
        'password': 'str'
    }

    attribute_map = {
        'name': 'name',
        'api_token': 'api_token',
        'create_api_token': 'create_api_token',
        'api_token_timeout': 'api_token_timeout',
        'delete_api_token': 'delete_api_token',
        'old_password': 'old_password',
        'password': 'password'
    }

    def __init__(self, name=None, api_token=None, create_api_token=None, api_token_timeout=None, delete_api_token=None, old_password=None, password=None):  # noqa: E501
        """Admin - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._api_token = None
        self._create_api_token = None
        self._api_token_timeout = None
        self._delete_api_token = None
        self._old_password = None
        self._password = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if api_token is not None:
            self.api_token = api_token
        if create_api_token is not None:
            self.create_api_token = create_api_token
        if api_token_timeout is not None:
            self.api_token_timeout = api_token_timeout
        if delete_api_token is not None:
            self.delete_api_token = delete_api_token
        if old_password is not None:
            self.old_password = old_password
        if password is not None:
            self.password = password

    @property
    def name(self):
        """Gets the name of this Admin.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this Admin.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Admin.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this Admin.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_token(self):
        """Gets the api_token of this Admin.  # noqa: E501


        :return: The api_token of this Admin.  # noqa: E501
        :rtype: AdminApiToken
        """
        return self._api_token

    @api_token.setter
    def api_token(self, api_token):
        """Sets the api_token of this Admin.


        :param api_token: The api_token of this Admin.  # noqa: E501
        :type: AdminApiToken
        """

        self._api_token = api_token

    @property
    def create_api_token(self):
        """Gets the create_api_token of this Admin.  # noqa: E501

        Create a new API token  # noqa: E501

        :return: The create_api_token of this Admin.  # noqa: E501
        :rtype: bool
        """
        return self._create_api_token

    @create_api_token.setter
    def create_api_token(self, create_api_token):
        """Sets the create_api_token of this Admin.

        Create a new API token  # noqa: E501

        :param create_api_token: The create_api_token of this Admin.  # noqa: E501
        :type: bool
        """

        self._create_api_token = create_api_token

    @property
    def api_token_timeout(self):
        """Gets the api_token_timeout of this Admin.  # noqa: E501

        Expire api-token after this period (in milliseconds).  # noqa: E501

        :return: The api_token_timeout of this Admin.  # noqa: E501
        :rtype: int
        """
        return self._api_token_timeout

    @api_token_timeout.setter
    def api_token_timeout(self, api_token_timeout):
        """Sets the api_token_timeout of this Admin.

        Expire api-token after this period (in milliseconds).  # noqa: E501

        :param api_token_timeout: The api_token_timeout of this Admin.  # noqa: E501
        :type: int
        """

        self._api_token_timeout = api_token_timeout

    @property
    def delete_api_token(self):
        """Gets the delete_api_token of this Admin.  # noqa: E501

        Delete this user's API token  # noqa: E501

        :return: The delete_api_token of this Admin.  # noqa: E501
        :rtype: bool
        """
        return self._delete_api_token

    @delete_api_token.setter
    def delete_api_token(self, delete_api_token):
        """Sets the delete_api_token of this Admin.

        Delete this user's API token  # noqa: E501

        :param delete_api_token: The delete_api_token of this Admin.  # noqa: E501
        :type: bool
        """

        self._delete_api_token = delete_api_token

    @property
    def old_password(self):
        """Gets the old_password of this Admin.  # noqa: E501

        Old user password  # noqa: E501

        :return: The old_password of this Admin.  # noqa: E501
        :rtype: str
        """
        return self._old_password

    @old_password.setter
    def old_password(self, old_password):
        """Sets the old_password of this Admin.

        Old user password  # noqa: E501

        :param old_password: The old_password of this Admin.  # noqa: E501
        :type: str
        """

        self._old_password = old_password

    @property
    def password(self):
        """Gets the password of this Admin.  # noqa: E501

        User password  # noqa: E501

        :return: The password of this Admin.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this Admin.

        User password  # noqa: E501

        :param password: The password of this Admin.  # noqa: E501
        :type: str
        """

        self._password = password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Admin, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Admin):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Keytab(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'encryption_type': 'str',
        'fqdn': 'str',
        'kvno': 'int',
        'prefix': 'str',
        'principal': 'str',
        'realm': 'str',
        'suffix': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'encryption_type': 'encryption_type',
        'fqdn': 'fqdn',
        'kvno': 'kvno',
        'prefix': 'prefix',
        'principal': 'principal',
        'realm': 'realm',
        'suffix': 'suffix'
    }

    def __init__(self, id=None, name=None, encryption_type=None, fqdn=None, kvno=None, prefix=None, principal=None, realm=None, suffix=None):  # noqa: E501
        """Keytab - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._encryption_type = None
        self._fqdn = None
        self._kvno = None
        self._prefix = None
        self._principal = None
        self._realm = None
        self._suffix = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if encryption_type is not None:
            self.encryption_type = encryption_type
        if fqdn is not None:
            self.fqdn = fqdn
        if kvno is not None:
            self.kvno = kvno
        if prefix is not None:
            self.prefix = prefix
        if principal is not None:
            self.principal = principal
        if realm is not None:
            self.realm = realm
        if suffix is not None:
            self.suffix = suffix

    @property
    def id(self):
        """Gets the id of this Keytab.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Keytab.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Keytab.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Keytab.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Keytab.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this Keytab.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def encryption_type(self):
        """Gets the encryption_type of this Keytab.  # noqa: E501

        The encryption type used by the kerberos domain controller to generate the keytab.  # noqa: E501

        :return: The encryption_type of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._encryption_type

    @encryption_type.setter
    def encryption_type(self, encryption_type):
        """Sets the encryption_type of this Keytab.

        The encryption type used by the kerberos domain controller to generate the keytab.  # noqa: E501

        :param encryption_type: The encryption_type of this Keytab.  # noqa: E501
        :type: str
        """

        self._encryption_type = encryption_type

    @property
    def fqdn(self):
        """Gets the fqdn of this Keytab.  # noqa: E501

        The fully qualified domain name to which the keytab was issued.  # noqa: E501

        :return: The fqdn of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """Sets the fqdn of this Keytab.

        The fully qualified domain name to which the keytab was issued.  # noqa: E501

        :param fqdn: The fqdn of this Keytab.  # noqa: E501
        :type: str
        """

        self._fqdn = fqdn

    @property
    def kvno(self):
        """Gets the kvno of this Keytab.  # noqa: E501

        The key version number of the key used to generate the keytab.  # noqa: E501

        :return: The kvno of this Keytab.  # noqa: E501
        :rtype: int
        """
        return self._kvno

    @kvno.setter
    def kvno(self, kvno):
        """Sets the kvno of this Keytab.

        The key version number of the key used to generate the keytab.  # noqa: E501

        :param kvno: The kvno of this Keytab.  # noqa: E501
        :type: int
        """

        self._kvno = kvno

    @property
    def prefix(self):
        """Gets the prefix of this Keytab.  # noqa: E501

        The prefix in the name of the keytab object. This is the same for all keytab objects created from a single keytab file. The name of a keytab entry is created in the format `<prefix>.<suffix>` for all entries.  # noqa: E501

        :return: The prefix of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this Keytab.

        The prefix in the name of the keytab object. This is the same for all keytab objects created from a single keytab file. The name of a keytab entry is created in the format `<prefix>.<suffix>` for all entries.  # noqa: E501

        :param prefix: The prefix of this Keytab.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    @property
    def principal(self):
        """Gets the principal of this Keytab.  # noqa: E501

        The service name for which the keytab was issued.  # noqa: E501

        :return: The principal of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._principal

    @principal.setter
    def principal(self, principal):
        """Sets the principal of this Keytab.

        The service name for which the keytab was issued.  # noqa: E501

        :param principal: The principal of this Keytab.  # noqa: E501
        :type: str
        """

        self._principal = principal

    @property
    def realm(self):
        """Gets the realm of this Keytab.  # noqa: E501

        The kerberos realm that issued the keytab.  # noqa: E501

        :return: The realm of this Keytab.  # noqa: E501
        :rtype: str
        """
        return self._realm

    @realm.setter
    def realm(self, realm):
        """Sets the realm of this Keytab.

        The kerberos realm that issued the keytab.  # noqa: E501

        :param realm: The realm of this Keytab.  # noqa: E501
        :type: str
        """

        self._realm = realm

    @property
    def suffix(self):
        """Gets the suffix of this Keytab.  # noqa: E501

        The suffix in the name of the keytab object, determined at creation time using the slot number of the keytab entry in a file and the number of existing entries with the same prefix. The name of a keytab entry is created in the format `<prefix>.<suffix>` for all entries.  # noqa: E501

        :return: The suffix of this Keytab.  # noqa: E501
        :rtype: int
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this Keytab.

        The suffix in the name of the keytab object, determined at creation time using the slot number of the keytab entry in a file and the number of existing entries with the same prefix. The name of a keytab entry is created in the format `<prefix>.<suffix>` for all entries.  # noqa: E501

        :param suffix: The suffix of this Keytab.  # noqa: E501
        :type: int
        """

        self._suffix = suffix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Keytab, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Keytab):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LifecycleRulePost(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bucket': 'Reference',
        'rule_id': 'str',
        'keep_previous_version_for': 'int',
        'prefix': 'str'
    }

    attribute_map = {
        'bucket': 'bucket',
        'rule_id': 'rule_id',
        'keep_previous_version_for': 'keep_previous_version_for',
        'prefix': 'prefix'
    }

    def __init__(self, bucket=None, rule_id=None, keep_previous_version_for=None, prefix=None):  # noqa: E501
        """LifecycleRulePost - a model defined in Swagger"""  # noqa: E501

        self._bucket = None
        self._rule_id = None
        self._keep_previous_version_for = None
        self._prefix = None
        self.discriminator = None

        self.bucket = bucket
        if rule_id is not None:
            self.rule_id = rule_id
        self.keep_previous_version_for = keep_previous_version_for
        if prefix is not None:
            self.prefix = prefix

    @property
    def bucket(self):
        """Gets the bucket of this LifecycleRulePost.  # noqa: E501

        The bucket name for lifecycle rule creation.  # noqa: E501

        :return: The bucket of this LifecycleRulePost.  # noqa: E501
        :rtype: Reference
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this LifecycleRulePost.

        The bucket name for lifecycle rule creation.  # noqa: E501

        :param bucket: The bucket of this LifecycleRulePost.  # noqa: E501
        :type: Reference
        """
        if bucket is None:
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def rule_id(self):
        """Gets the rule_id of this LifecycleRulePost.  # noqa: E501

        Identifier for the rule that is unique to the bucket that it applies to. Can have a maximum length of 255 characters. If not specified, an id unique to the bucket will be generated in the format `fbRuleId<number>` where number increments, starting at 1.  # noqa: E501

        :return: The rule_id of this LifecycleRulePost.  # noqa: E501
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """Sets the rule_id of this LifecycleRulePost.

        Identifier for the rule that is unique to the bucket that it applies to. Can have a maximum length of 255 characters. If not specified, an id unique to the bucket will be generated in the format `fbRuleId<number>` where number increments, starting at 1.  # noqa: E501

        :param rule_id: The rule_id of this LifecycleRulePost.  # noqa: E501
        :type: str
        """

        self._rule_id = rule_id

    @property
    def keep_previous_version_for(self):
        """Gets the keep_previous_version_for of this LifecycleRulePost.  # noqa: E501

        Time after which previous versions will be marked expired. Measured in milliseconds. Must be a multiple of 86400000 to represent a whole number of days.  # noqa: E501

        :return: The keep_previous_version_for of this LifecycleRulePost.  # noqa: E501
        :rtype: int
        """
        return self._keep_previous_version_for

    @keep_previous_version_for.setter
    def keep_previous_version_for(self, keep_previous_version_for):
        """Sets the keep_previous_version_for of this LifecycleRulePost.

        Time after which previous versions will be marked expired. Measured in milliseconds. Must be a multiple of 86400000 to represent a whole number of days.  # noqa: E501

        :param keep_previous_version_for: The keep_previous_version_for of this LifecycleRulePost.  # noqa: E501
        :type: int
        """
        if keep_previous_version_for is None:
            raise ValueError("Invalid value for `keep_previous_version_for`, must not be `None`")  # noqa: E501

        self._keep_previous_version_for = keep_previous_version_for

    @property
    def prefix(self):
        """Gets the prefix of this LifecycleRulePost.  # noqa: E501

        Object key prefix identifying one or more objects in the bucket. Can have a maximum length of 1024 characters.  # noqa: E501

        :return: The prefix of this LifecycleRulePost.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this LifecycleRulePost.

        Object key prefix identifying one or more objects in the bucket. Can have a maximum length of 1024 characters.  # noqa: E501

        :param prefix: The prefix of this LifecycleRulePost.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LifecycleRulePost, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LifecycleRulePost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from purity_fb.apis import *
from purity_fb.api_client import ApiClient
from purity_fb import rest

from distutils.version import LooseVersion
import ssl
import urllib3

FILE_SYSTEMS = 'FileSystems'
FILE_SYSTEM_SNAPSHOTS = 'FileSystemSnapshots'

SUPPORTED_VERSIONS = ['1.0', '1.1', '1.2']

class PurityFb:
    DEFAULT_READ_TIMEOUT = 30.0
    DEFAULT_CONN_TIMEOUT = 10.0
    DEFAULT_RETRIES = 5

    def __init__(self, host, version=None, api_token=None, ca_certs_file_path=None):
        self._api_client = ApiClient(host='https://{}/api'.format(host))
        self.request_timeout = urllib3.Timeout(
            connect=PurityFb.DEFAULT_CONN_TIMEOUT,
            read=PurityFb.DEFAULT_READ_TIMEOUT)
        self.retries = urllib3.Retry(total=PurityFb.DEFAULT_RETRIES)
        
        if not ca_certs_file_path:
            self.disable_verify_ssl()
        else:
            self.configure_ca_certificate_file(ca_certs_file_path)
            self.enable_verify_ssl()

        self._api_version = VersionApi(api_client=self._api_client)
        if version:
            self._version = self._check_rest_version(version)
        else:
            self._version = self._choose_rest_version()
        self._auth = AuthenticationApi(api_client=self._api_client)

        self._file_systems = globals()[self._class_name(FILE_SYSTEMS, self._version)](api_client=self._api_client)
        self._file_system_snapshots = globals()[self._class_name(FILE_SYSTEM_SNAPSHOTS, self._version)](
            api_client=self._api_client)

        if self._version >= LooseVersion('1.2'):
            self._admins = AdminsApi(api_client=self._api_client)
            self._alerts = AlertsApi(api_client=self._api_client)
            self._alert_watchers = AlertWatchersApi(api_client=self._api_client)
            self._arrays = ArraysApi(api_client=self._api_client)
            self._blade = BladeApi(api_client=self._api_client)
            self._certificates = CertificatesApi(api_client=self._api_client)
            self._dns = DnsApi(api_client=self._api_client)
            self._hardware = HardwareApi(api_client=self._api_client)

        if api_token:
            self.login(api_token)
        self.enable_verify_ssl()

    def _class_name(self, api, version):
        return api + str(version).replace('.', 'dot') + 'Api'

    def _choose_rest_version(self):
        """Return the newest REST API version supported by target array."""
        versions = self.list_versions()
        versions = [LooseVersion(x) for x in versions if x in SUPPORTED_VERSIONS]
        if versions:
            return max(versions)
        else:
            raise RuntimeError(
                "Library is incompatible with all REST API versions supported"
                "by the target array.")

    def _check_rest_version(self, version):
        """Validate a REST API version is supported by the library and target array."""
        version = str(version)

        if version not in SUPPORTED_VERSIONS:
            msg = "Library is incompatible with REST API version {0}"
            raise ValueError(msg.format(version))

        array_rest_versions = self.list_versions()
        if version not in array_rest_versions:
            msg = "Array is incompatible with REST API version {0}"
            raise ValueError(msg.format(version))

        return LooseVersion(version)

    def list_versions(self):
        try:
            return self._api_version.list_versions().versions
        except rest.ApiException:
            return ['1.0']

    def login(self, api_token):
        try:
            self.logout()
        except rest.ApiException:
            pass
        res = self._auth.login_with_http_info(api_token=api_token)
        self._api_client.default_headers['x-auth-token'] = res[2]['x-auth-token']
        return res[1]

    def logout(self):
        return self._auth.logout_with_http_info()[1]

    def allow_verify_ssl(self, ca_certs_file_path=None):
        """ Change our certificate requirements so that a certificate is validated if provided,
        but a certificate is not required.
        Optionally, if a CA certificate(s) file path is provided, configure the client to use
        that CA certificate file.
        """
        if ca_certs_file_path:
            self.configure_ca_certificate_file(ca_certs_file_path)
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_OPTIONAL

    def disable_verify_ssl(self):
        """ Change our certificate requirements so that a certificate is validated if provided,
        but a certificate is not required.
        """
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_NONE

    def enable_verify_ssl(self, ca_certs_file_path=None):
        """ Change our certificate requirements so that a certificate is required and validated.
        Optionally, if a CA certificate(s) file path is provided, configure the client to use
        that CA certificate file.
        """
        if ca_certs_file_path:
            self.configure_ca_certificate_file(ca_certs_file_path)
        self._api_client.rest_client.pool_manager.connection_pool_kw['cert_reqs'] = ssl.CERT_REQUIRED

    def configure_ca_certificate_file(self, ca_certs_file_path):
        """"
        :param ca_certs_file_path: The path to the CA certificate(s) file to use.
        :return:
        """
        self._api_client.rest_client.pool_manager.connection_pool_kw['ca_certs'] = ca_certs_file_path

    @property
    def request_timeout(self):
        return self._api_client.rest_client.pool_manager.connection_pool_kw['timeout']

    @request_timeout.setter
    def request_timeout(self, value):
        self._api_client.rest_client.pool_manager.connection_pool_kw['timeout'] = value

    @property
    def request_retry(self):
        return self._api_client.rest_client.pool_manager.connection_pool_kw['retries']

    @request_retry.setter
    def request_retry(self, value):
        self._api_client.rest_client.pool_manager.connection_pool_kw['retries'] = value

    @property
    def api_version(self):
        return self._api_version

    @property
    def authentication(self):
        return self._auth

    @property
    def admins(self):
        return self._admins

    @property
    def alerts(self):
        return self._alerts

    @property
    def alert_watchers(self):
        return self._alert_watchers

    @property
    def arrays(self):
        return self._arrays

    @property
    def blade(self):
        return self._blade

    @property
    def certificates(self):
        return self._certificates

    @property
    def dns(self):
        return self._dns

    @property
    def file_systems(self):
        return self._file_systems

    @property
    def file_system_snapshots(self):
        return self._file_system_snapshots

    @property
    def hardware(self):
        return self._hardware



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Bucket(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'created': 'int',
        'id': 'str',
        'space': 'Space',
        'account': 'Reference',
        'destroyed': 'bool',
        'time_remaining': 'int',
        'object_count': 'int',
        'versioning': 'str'
    }

    attribute_map = {
        'name': 'name',
        'created': 'created',
        'id': 'id',
        'space': 'space',
        'account': 'account',
        'destroyed': 'destroyed',
        'time_remaining': 'time_remaining',
        'object_count': 'object_count',
        'versioning': 'versioning'
    }

    def __init__(self, name=None, created=None, id=None, space=None, account=None, destroyed=None, time_remaining=None, object_count=None, versioning=None):  # noqa: E501
        """Bucket - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._created = None
        self._id = None
        self._space = None
        self._account = None
        self._destroyed = None
        self._time_remaining = None
        self._object_count = None
        self._versioning = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if created is not None:
            self.created = created
        if id is not None:
            self.id = id
        if space is not None:
            self.space = space
        if account is not None:
            self.account = account
        if destroyed is not None:
            self.destroyed = destroyed
        if time_remaining is not None:
            self.time_remaining = time_remaining
        if object_count is not None:
            self.object_count = object_count
        if versioning is not None:
            self.versioning = versioning

    @property
    def name(self):
        """Gets the name of this Bucket.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Bucket.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this Bucket.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def created(self):
        """Gets the created of this Bucket.  # noqa: E501

        Creation timestamp of the object  # noqa: E501

        :return: The created of this Bucket.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Bucket.

        Creation timestamp of the object  # noqa: E501

        :param created: The created of this Bucket.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def id(self):
        """Gets the id of this Bucket.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Bucket.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Bucket.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def space(self):
        """Gets the space of this Bucket.  # noqa: E501

        The space specification of the bucket.  # noqa: E501

        :return: The space of this Bucket.  # noqa: E501
        :rtype: Space
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this Bucket.

        The space specification of the bucket.  # noqa: E501

        :param space: The space of this Bucket.  # noqa: E501
        :type: Space
        """

        self._space = space

    @property
    def account(self):
        """Gets the account of this Bucket.  # noqa: E501

        The account of the bucket.  # noqa: E501

        :return: The account of this Bucket.  # noqa: E501
        :rtype: Reference
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Bucket.

        The account of the bucket.  # noqa: E501

        :param account: The account of this Bucket.  # noqa: E501
        :type: Reference
        """

        self._account = account

    @property
    def destroyed(self):
        """Gets the destroyed of this Bucket.  # noqa: E501

        Is the bucket destroyed?  # noqa: E501

        :return: The destroyed of this Bucket.  # noqa: E501
        :rtype: bool
        """
        return self._destroyed

    @destroyed.setter
    def destroyed(self, destroyed):
        """Sets the destroyed of this Bucket.

        Is the bucket destroyed?  # noqa: E501

        :param destroyed: The destroyed of this Bucket.  # noqa: E501
        :type: bool
        """

        self._destroyed = destroyed

    @property
    def time_remaining(self):
        """Gets the time_remaining of this Bucket.  # noqa: E501

        Time in milliseconds before the bucket is eradicated. Null if not destroyed.  # noqa: E501

        :return: The time_remaining of this Bucket.  # noqa: E501
        :rtype: int
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this Bucket.

        Time in milliseconds before the bucket is eradicated. Null if not destroyed.  # noqa: E501

        :param time_remaining: The time_remaining of this Bucket.  # noqa: E501
        :type: int
        """

        self._time_remaining = time_remaining

    @property
    def object_count(self):
        """Gets the object_count of this Bucket.  # noqa: E501

        The number of object within the bucket.  # noqa: E501

        :return: The object_count of this Bucket.  # noqa: E501
        :rtype: int
        """
        return self._object_count

    @object_count.setter
    def object_count(self, object_count):
        """Sets the object_count of this Bucket.

        The number of object within the bucket.  # noqa: E501

        :param object_count: The object_count of this Bucket.  # noqa: E501
        :type: int
        """

        self._object_count = object_count

    @property
    def versioning(self):
        """Gets the versioning of this Bucket.  # noqa: E501

        The versioning state for objects within the bucket. Valid values are `none`, `enabled`, and `suspended`.  # noqa: E501

        :return: The versioning of this Bucket.  # noqa: E501
        :rtype: str
        """
        return self._versioning

    @versioning.setter
    def versioning(self, versioning):
        """Sets the versioning of this Bucket.

        The versioning state for objects within the bucket. Valid values are `none`, `enabled`, and `suspended`.  # noqa: E501

        :param versioning: The versioning of this Bucket.  # noqa: E501
        :type: str
        """

        self._versioning = versioning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Bucket, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Bucket):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.3 Python SDK

    Pure Storage FlashBlade REST 1.3 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.3
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileSystem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'created': 'int',
        'fast_remove_directory_enabled': 'bool',
        'provisioned': 'int',
        'snapshot_directory_enabled': 'bool',
        'nfs': 'NfsRule',
        'http': 'ProtocolRule',
        'smb': 'SmbRule',
        'destroyed': 'bool',
        'time_remaining': 'int',
        'space': 'Space'
    }

    attribute_map = {
        'name': 'name',
        'created': 'created',
        'fast_remove_directory_enabled': 'fast_remove_directory_enabled',
        'provisioned': 'provisioned',
        'snapshot_directory_enabled': 'snapshot_directory_enabled',
        'nfs': 'nfs',
        'http': 'http',
        'smb': 'smb',
        'destroyed': 'destroyed',
        'time_remaining': 'time_remaining',
        'space': 'space'
    }

    def __init__(self, name=None, created=None, fast_remove_directory_enabled=None, provisioned=None, snapshot_directory_enabled=None, nfs=None, http=None, smb=None, destroyed=None, time_remaining=None, space=None):  # noqa: E501
        """FileSystem - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._created = None
        self._fast_remove_directory_enabled = None
        self._provisioned = None
        self._snapshot_directory_enabled = None
        self._nfs = None
        self._http = None
        self._smb = None
        self._destroyed = None
        self._time_remaining = None
        self._space = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if created is not None:
            self.created = created
        if fast_remove_directory_enabled is not None:
            self.fast_remove_directory_enabled = fast_remove_directory_enabled
        if provisioned is not None:
            self.provisioned = provisioned
        if snapshot_directory_enabled is not None:
            self.snapshot_directory_enabled = snapshot_directory_enabled
        if nfs is not None:
            self.nfs = nfs
        if http is not None:
            self.http = http
        if smb is not None:
            self.smb = smb
        if destroyed is not None:
            self.destroyed = destroyed
        if time_remaining is not None:
            self.time_remaining = time_remaining
        if space is not None:
            self.space = space

    @property
    def name(self):
        """Gets the name of this FileSystem.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this FileSystem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileSystem.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this FileSystem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def created(self):
        """Gets the created of this FileSystem.  # noqa: E501

        Creation timestamp of the object  # noqa: E501

        :return: The created of this FileSystem.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FileSystem.

        Creation timestamp of the object  # noqa: E501

        :param created: The created of this FileSystem.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def fast_remove_directory_enabled(self):
        """Gets the fast_remove_directory_enabled of this FileSystem.  # noqa: E501

        is fast remove directory enabled? Modifiable. Default false when creating a new file-system  # noqa: E501

        :return: The fast_remove_directory_enabled of this FileSystem.  # noqa: E501
        :rtype: bool
        """
        return self._fast_remove_directory_enabled

    @fast_remove_directory_enabled.setter
    def fast_remove_directory_enabled(self, fast_remove_directory_enabled):
        """Sets the fast_remove_directory_enabled of this FileSystem.

        is fast remove directory enabled? Modifiable. Default false when creating a new file-system  # noqa: E501

        :param fast_remove_directory_enabled: The fast_remove_directory_enabled of this FileSystem.  # noqa: E501
        :type: bool
        """

        self._fast_remove_directory_enabled = fast_remove_directory_enabled

    @property
    def provisioned(self):
        """Gets the provisioned of this FileSystem.  # noqa: E501

        the provisioned size of the file system in bytes. Modifiable. Default 0 when creating a new file-system  # noqa: E501

        :return: The provisioned of this FileSystem.  # noqa: E501
        :rtype: int
        """
        return self._provisioned

    @provisioned.setter
    def provisioned(self, provisioned):
        """Sets the provisioned of this FileSystem.

        the provisioned size of the file system in bytes. Modifiable. Default 0 when creating a new file-system  # noqa: E501

        :param provisioned: The provisioned of this FileSystem.  # noqa: E501
        :type: int
        """

        self._provisioned = provisioned

    @property
    def snapshot_directory_enabled(self):
        """Gets the snapshot_directory_enabled of this FileSystem.  # noqa: E501

        is snapshot directory enabled? Modifiable. Default false when creating a new file-system  # noqa: E501

        :return: The snapshot_directory_enabled of this FileSystem.  # noqa: E501
        :rtype: bool
        """
        return self._snapshot_directory_enabled

    @snapshot_directory_enabled.setter
    def snapshot_directory_enabled(self, snapshot_directory_enabled):
        """Sets the snapshot_directory_enabled of this FileSystem.

        is snapshot directory enabled? Modifiable. Default false when creating a new file-system  # noqa: E501

        :param snapshot_directory_enabled: The snapshot_directory_enabled of this FileSystem.  # noqa: E501
        :type: bool
        """

        self._snapshot_directory_enabled = snapshot_directory_enabled

    @property
    def nfs(self):
        """Gets the nfs of this FileSystem.  # noqa: E501

        NFS configuration. Modifiable.  # noqa: E501

        :return: The nfs of this FileSystem.  # noqa: E501
        :rtype: NfsRule
        """
        return self._nfs

    @nfs.setter
    def nfs(self, nfs):
        """Sets the nfs of this FileSystem.

        NFS configuration. Modifiable.  # noqa: E501

        :param nfs: The nfs of this FileSystem.  # noqa: E501
        :type: NfsRule
        """

        self._nfs = nfs

    @property
    def http(self):
        """Gets the http of this FileSystem.  # noqa: E501

        HTTP configuration. Modifiable.  # noqa: E501

        :return: The http of this FileSystem.  # noqa: E501
        :rtype: ProtocolRule
        """
        return self._http

    @http.setter
    def http(self, http):
        """Sets the http of this FileSystem.

        HTTP configuration. Modifiable.  # noqa: E501

        :param http: The http of this FileSystem.  # noqa: E501
        :type: ProtocolRule
        """

        self._http = http

    @property
    def smb(self):
        """Gets the smb of this FileSystem.  # noqa: E501

        SMB configuration. Modifiable.  # noqa: E501

        :return: The smb of this FileSystem.  # noqa: E501
        :rtype: SmbRule
        """
        return self._smb

    @smb.setter
    def smb(self, smb):
        """Sets the smb of this FileSystem.

        SMB configuration. Modifiable.  # noqa: E501

        :param smb: The smb of this FileSystem.  # noqa: E501
        :type: SmbRule
        """

        self._smb = smb

    @property
    def destroyed(self):
        """Gets the destroyed of this FileSystem.  # noqa: E501

        is the file system destroyed? False by default. Modifiable.  # noqa: E501

        :return: The destroyed of this FileSystem.  # noqa: E501
        :rtype: bool
        """
        return self._destroyed

    @destroyed.setter
    def destroyed(self, destroyed):
        """Sets the destroyed of this FileSystem.

        is the file system destroyed? False by default. Modifiable.  # noqa: E501

        :param destroyed: The destroyed of this FileSystem.  # noqa: E501
        :type: bool
        """

        self._destroyed = destroyed

    @property
    def time_remaining(self):
        """Gets the time_remaining of this FileSystem.  # noqa: E501

        time in milliseconds before the file system is eradicated. Null if not destroyed.  # noqa: E501

        :return: The time_remaining of this FileSystem.  # noqa: E501
        :rtype: int
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this FileSystem.

        time in milliseconds before the file system is eradicated. Null if not destroyed.  # noqa: E501

        :param time_remaining: The time_remaining of this FileSystem.  # noqa: E501
        :type: int
        """

        self._time_remaining = time_remaining

    @property
    def space(self):
        """Gets the space of this FileSystem.  # noqa: E501

        the space specification of the file system  # noqa: E501

        :return: The space of this FileSystem.  # noqa: E501
        :rtype: Space
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this FileSystem.

        the space specification of the file system  # noqa: E501

        :param space: The space of this FileSystem.  # noqa: E501
        :type: Space
        """

        self._space = space

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileSystem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSystem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Certificate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'certificate': 'str',
        'certificate_type': 'str',
        'common_name': 'str',
        'country': 'str',
        'email': 'str',
        'intermediate_certificate': 'str',
        'issued_by': 'str',
        'issued_to': 'str',
        'key_size': 'int',
        'locality': 'str',
        'organization': 'str',
        'organizational_unit': 'str',
        'state': 'str',
        'status': 'str',
        'valid_from': 'str',
        'valid_to': 'str',
        'passphrase': 'str',
        'private_key': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'certificate': 'certificate',
        'certificate_type': 'certificate_type',
        'common_name': 'common_name',
        'country': 'country',
        'email': 'email',
        'intermediate_certificate': 'intermediate_certificate',
        'issued_by': 'issued_by',
        'issued_to': 'issued_to',
        'key_size': 'key_size',
        'locality': 'locality',
        'organization': 'organization',
        'organizational_unit': 'organizational_unit',
        'state': 'state',
        'status': 'status',
        'valid_from': 'valid_from',
        'valid_to': 'valid_to',
        'passphrase': 'passphrase',
        'private_key': 'private_key'
    }

    def __init__(self, id=None, name=None, certificate=None, certificate_type=None, common_name=None, country=None, email=None, intermediate_certificate=None, issued_by=None, issued_to=None, key_size=None, locality=None, organization=None, organizational_unit=None, state=None, status=None, valid_from=None, valid_to=None, passphrase=None, private_key=None):  # noqa: E501
        """Certificate - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._certificate = None
        self._certificate_type = None
        self._common_name = None
        self._country = None
        self._email = None
        self._intermediate_certificate = None
        self._issued_by = None
        self._issued_to = None
        self._key_size = None
        self._locality = None
        self._organization = None
        self._organizational_unit = None
        self._state = None
        self._status = None
        self._valid_from = None
        self._valid_to = None
        self._passphrase = None
        self._private_key = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if certificate is not None:
            self.certificate = certificate
        if certificate_type is not None:
            self.certificate_type = certificate_type
        if common_name is not None:
            self.common_name = common_name
        if country is not None:
            self.country = country
        if email is not None:
            self.email = email
        if intermediate_certificate is not None:
            self.intermediate_certificate = intermediate_certificate
        if issued_by is not None:
            self.issued_by = issued_by
        if issued_to is not None:
            self.issued_to = issued_to
        if key_size is not None:
            self.key_size = key_size
        if locality is not None:
            self.locality = locality
        if organization is not None:
            self.organization = organization
        if organizational_unit is not None:
            self.organizational_unit = organizational_unit
        if state is not None:
            self.state = state
        if status is not None:
            self.status = status
        if valid_from is not None:
            self.valid_from = valid_from
        if valid_to is not None:
            self.valid_to = valid_to
        if passphrase is not None:
            self.passphrase = passphrase
        if private_key is not None:
            self.private_key = private_key

    @property
    def id(self):
        """Gets the id of this Certificate.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Certificate.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Certificate.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Certificate.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Certificate.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this Certificate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def certificate(self):
        """Gets the certificate of this Certificate.  # noqa: E501

        The text of the certificate.  # noqa: E501

        :return: The certificate of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this Certificate.

        The text of the certificate.  # noqa: E501

        :param certificate: The certificate of this Certificate.  # noqa: E501
        :type: str
        """

        self._certificate = certificate

    @property
    def certificate_type(self):
        """Gets the certificate_type of this Certificate.  # noqa: E501

        The type of certificate. Possible values are `array` and `external`. Certificates of type `array` are used by the array to verify its identity to clients. Certificates of type `external` are used by the array to identify external servers to which it is configured to communicate.  # noqa: E501

        :return: The certificate_type of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._certificate_type

    @certificate_type.setter
    def certificate_type(self, certificate_type):
        """Sets the certificate_type of this Certificate.

        The type of certificate. Possible values are `array` and `external`. Certificates of type `array` are used by the array to verify its identity to clients. Certificates of type `external` are used by the array to identify external servers to which it is configured to communicate.  # noqa: E501

        :param certificate_type: The certificate_type of this Certificate.  # noqa: E501
        :type: str
        """

        self._certificate_type = certificate_type

    @property
    def common_name(self):
        """Gets the common_name of this Certificate.  # noqa: E501

        FQDN or management IP address of the machine presenting the certificate.  # noqa: E501

        :return: The common_name of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """Sets the common_name of this Certificate.

        FQDN or management IP address of the machine presenting the certificate.  # noqa: E501

        :param common_name: The common_name of this Certificate.  # noqa: E501
        :type: str
        """

        self._common_name = common_name

    @property
    def country(self):
        """Gets the country of this Certificate.  # noqa: E501

        The country field listed in the certificate.  # noqa: E501

        :return: The country of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Certificate.

        The country field listed in the certificate.  # noqa: E501

        :param country: The country of this Certificate.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def email(self):
        """Gets the email of this Certificate.  # noqa: E501

        The email field listed in the certificate.  # noqa: E501

        :return: The email of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Certificate.

        The email field listed in the certificate.  # noqa: E501

        :param email: The email of this Certificate.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def intermediate_certificate(self):
        """Gets the intermediate_certificate of this Certificate.  # noqa: E501

        Intermediate certificate chains.  # noqa: E501

        :return: The intermediate_certificate of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._intermediate_certificate

    @intermediate_certificate.setter
    def intermediate_certificate(self, intermediate_certificate):
        """Sets the intermediate_certificate of this Certificate.

        Intermediate certificate chains.  # noqa: E501

        :param intermediate_certificate: The intermediate_certificate of this Certificate.  # noqa: E501
        :type: str
        """

        self._intermediate_certificate = intermediate_certificate

    @property
    def issued_by(self):
        """Gets the issued_by of this Certificate.  # noqa: E501

        Who issued this certificate.  # noqa: E501

        :return: The issued_by of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._issued_by

    @issued_by.setter
    def issued_by(self, issued_by):
        """Sets the issued_by of this Certificate.

        Who issued this certificate.  # noqa: E501

        :param issued_by: The issued_by of this Certificate.  # noqa: E501
        :type: str
        """

        self._issued_by = issued_by

    @property
    def issued_to(self):
        """Gets the issued_to of this Certificate.  # noqa: E501

        Who this certificate was issued to.  # noqa: E501

        :return: The issued_to of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._issued_to

    @issued_to.setter
    def issued_to(self, issued_to):
        """Sets the issued_to of this Certificate.

        Who this certificate was issued to.  # noqa: E501

        :param issued_to: The issued_to of this Certificate.  # noqa: E501
        :type: str
        """

        self._issued_to = issued_to

    @property
    def key_size(self):
        """Gets the key_size of this Certificate.  # noqa: E501

        The size of the private key for this certificate in bits.  # noqa: E501

        :return: The key_size of this Certificate.  # noqa: E501
        :rtype: int
        """
        return self._key_size

    @key_size.setter
    def key_size(self, key_size):
        """Sets the key_size of this Certificate.

        The size of the private key for this certificate in bits.  # noqa: E501

        :param key_size: The key_size of this Certificate.  # noqa: E501
        :type: int
        """

        self._key_size = key_size

    @property
    def locality(self):
        """Gets the locality of this Certificate.  # noqa: E501

        The locality field listed in the certificate.  # noqa: E501

        :return: The locality of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this Certificate.

        The locality field listed in the certificate.  # noqa: E501

        :param locality: The locality of this Certificate.  # noqa: E501
        :type: str
        """

        self._locality = locality

    @property
    def organization(self):
        """Gets the organization of this Certificate.  # noqa: E501

        The organization field listed in the certificate.  # noqa: E501

        :return: The organization of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this Certificate.

        The organization field listed in the certificate.  # noqa: E501

        :param organization: The organization of this Certificate.  # noqa: E501
        :type: str
        """

        self._organization = organization

    @property
    def organizational_unit(self):
        """Gets the organizational_unit of this Certificate.  # noqa: E501

        The organizational unit field listed in the certificate.  # noqa: E501

        :return: The organizational_unit of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._organizational_unit

    @organizational_unit.setter
    def organizational_unit(self, organizational_unit):
        """Sets the organizational_unit of this Certificate.

        The organizational unit field listed in the certificate.  # noqa: E501

        :param organizational_unit: The organizational_unit of this Certificate.  # noqa: E501
        :type: str
        """

        self._organizational_unit = organizational_unit

    @property
    def state(self):
        """Gets the state of this Certificate.  # noqa: E501

        The state/province field listed in the certificate.  # noqa: E501

        :return: The state of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Certificate.

        The state/province field listed in the certificate.  # noqa: E501

        :param state: The state of this Certificate.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def status(self):
        """Gets the status of this Certificate.  # noqa: E501

        The type of certificate. Possible values are self-signed and imported.  # noqa: E501

        :return: The status of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Certificate.

        The type of certificate. Possible values are self-signed and imported.  # noqa: E501

        :param status: The status of this Certificate.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def valid_from(self):
        """Gets the valid_from of this Certificate.  # noqa: E501

        The start date of when this certificate is valid.  # noqa: E501

        :return: The valid_from of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._valid_from

    @valid_from.setter
    def valid_from(self, valid_from):
        """Sets the valid_from of this Certificate.

        The start date of when this certificate is valid.  # noqa: E501

        :param valid_from: The valid_from of this Certificate.  # noqa: E501
        :type: str
        """

        self._valid_from = valid_from

    @property
    def valid_to(self):
        """Gets the valid_to of this Certificate.  # noqa: E501

        The end date of when this certificate is valid.  # noqa: E501

        :return: The valid_to of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._valid_to

    @valid_to.setter
    def valid_to(self, valid_to):
        """Sets the valid_to of this Certificate.

        The end date of when this certificate is valid.  # noqa: E501

        :param valid_to: The valid_to of this Certificate.  # noqa: E501
        :type: str
        """

        self._valid_to = valid_to

    @property
    def passphrase(self):
        """Gets the passphrase of this Certificate.  # noqa: E501

        The passphrase used to encrypt the private key.  # noqa: E501

        :return: The passphrase of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """Sets the passphrase of this Certificate.

        The passphrase used to encrypt the private key.  # noqa: E501

        :param passphrase: The passphrase of this Certificate.  # noqa: E501
        :type: str
        """

        self._passphrase = passphrase

    @property
    def private_key(self):
        """Gets the private_key of this Certificate.  # noqa: E501

        The private key used to sign the certificate.  # noqa: E501

        :return: The private_key of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this Certificate.

        The private key used to sign the certificate.  # noqa: E501

        :param private_key: The private_key of this Certificate.  # noqa: E501
        :type: str
        """

        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Certificate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Certificate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class UsageUsersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def list_user_usage(self, **kwargs):
        """
        A list of usage user entries
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_user_usage(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param int limit: limit, should be >= 0
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param list[str] file_system_names: A comma-separated list of file system names. If after filtering, there is not at least one resource that matches each of the elements of names, then an error is returned.
        :param list[str] uids: A comma-separated list of user IDs. If after filtering, there is not at least one resource that matches each of the elements of user IDs, then an error is returned. This cannot be provided together with user_names query parameter.
        :return: QuotasUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_user_usage_with_http_info(**kwargs)
        else:
            (data) = self.list_user_usage_with_http_info(**kwargs)
            return data

    def list_user_usage_with_http_info(self, **kwargs):
        """
        A list of usage user entries
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_user_usage_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param int limit: limit, should be >= 0
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param list[str] file_system_names: A comma-separated list of file system names. If after filtering, there is not at least one resource that matches each of the elements of names, then an error is returned.
        :param list[str] uids: A comma-separated list of user IDs. If after filtering, there is not at least one resource that matches each of the elements of user IDs, then an error is returned. This cannot be provided together with user_names query parameter.
        :return: QuotasUserResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['names', 'filter', 'limit', 'sort', 'start', 'token', 'file_system_names', 'uids']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_user_usage" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'file_system_names' in params:
            query_params.append(('file_system_names', params['file_system_names']))
            collection_formats['file_system_names'] = 'csv'
        if 'uids' in params:
            query_params.append(('uids', params['uids']))
            collection_formats['uids'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.8/usage/users', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='QuotasUserResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.2 Python SDK

    Pure Storage FlashBlade REST 1.2 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.2
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.admin import Admin
from .models.admin_api_token import AdminApiToken
from .models.admin_response import AdminResponse
from .models.alert import Alert
from .models.alert_response import AlertResponse
from .models.alert_watcher import AlertWatcher
from .models.alert_watcher_response import AlertWatcherResponse
from .models.alert_watcher_test import AlertWatcherTest
from .models.alert_watcher_test_response import AlertWatcherTestResponse
from .models.array_http_performance import ArrayHttpPerformance
from .models.array_http_performance_response import ArrayHttpPerformanceResponse
from .models.array_performance import ArrayPerformance
from .models.array_performance_response import ArrayPerformanceResponse
from .models.array_s3_performance import ArrayS3Performance
from .models.array_s3_performance_response import ArrayS3PerformanceResponse
from .models.array_space import ArraySpace
from .models.array_space_response import ArraySpaceResponse
from .models.blade import Blade
from .models.blade_response import BladeResponse
from .models._built_in import BuiltIn
from .models.certificate import Certificate
from .models.certificate_response import CertificateResponse
from .models.dns import Dns
from .models.dns_response import DnsResponse
from .models.error_response import ErrorResponse
from .models.file_system import FileSystem
from .models.file_system_response import FileSystemResponse
from .models.file_system_snapshot import FileSystemSnapshot
from .models.file_system_snapshot_response import FileSystemSnapshotResponse
from .models.hardware import Hardware
from .models.hardware_response import HardwareResponse
from .models.login_response import LoginResponse
from .models.nfs_rule import NfsRule
from .models.object_response import ObjectResponse
from .models.pagination_info import PaginationInfo
from .models.protocol_rule import ProtocolRule
from .models.pure_error import PureError
from .models.pure_object import PureObject
from .models.smb_rule import SmbRule
from .models.snapshot_suffix import SnapshotSuffix
from .models.space import Space
from .models.version_response import VersionResponse

# import apis into sdk package
from .apis.admins_api import AdminsApi
from .apis.alert_watchers_api import AlertWatchersApi
from .apis.alerts_api import AlertsApi
from .apis.arrays_api import ArraysApi
from .apis.authentication_api import AuthenticationApi
from .apis.blade_api import BladeApi
from .apis.certificates_api import CertificatesApi
from .apis.dns_api import DnsApi
from .apis.file_system_snapshots_api import FileSystemSnapshotsApi
from .apis.file_systems_api import FileSystemsApi
from .apis.hardware_api import HardwareApi
from .apis.version_api import VersionApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Audit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'arguments': 'str',
        'command': 'str',
        'ip_address': 'str',
        'subcommand': 'str',
        'time': 'int',
        'user': 'str',
        'user_agent': 'str',
        'user_interface': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'arguments': 'arguments',
        'command': 'command',
        'ip_address': 'ip_address',
        'subcommand': 'subcommand',
        'time': 'time',
        'user': 'user',
        'user_agent': 'user_agent',
        'user_interface': 'user_interface'
    }

    def __init__(self, id=None, name=None, arguments=None, command=None, ip_address=None, subcommand=None, time=None, user=None, user_agent=None, user_interface=None):  # noqa: E501
        """Audit - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._arguments = None
        self._command = None
        self._ip_address = None
        self._subcommand = None
        self._time = None
        self._user = None
        self._user_agent = None
        self._user_interface = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if arguments is not None:
            self.arguments = arguments
        if command is not None:
            self.command = command
        if ip_address is not None:
            self.ip_address = ip_address
        if subcommand is not None:
            self.subcommand = subcommand
        if time is not None:
            self.time = time
        if user is not None:
            self.user = user
        if user_agent is not None:
            self.user_agent = user_agent
        if user_interface is not None:
            self.user_interface = user_interface

    @property
    def id(self):
        """Gets the id of this Audit.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Audit.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Audit.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Audit.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Audit.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this Audit.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def arguments(self):
        """Gets the arguments of this Audit.  # noqa: E501


        :return: The arguments of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this Audit.


        :param arguments: The arguments of this Audit.  # noqa: E501
        :type: str
        """

        self._arguments = arguments

    @property
    def command(self):
        """Gets the command of this Audit.  # noqa: E501


        :return: The command of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this Audit.


        :param command: The command of this Audit.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def ip_address(self):
        """Gets the ip_address of this Audit.  # noqa: E501


        :return: The ip_address of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this Audit.


        :param ip_address: The ip_address of this Audit.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def subcommand(self):
        """Gets the subcommand of this Audit.  # noqa: E501


        :return: The subcommand of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._subcommand

    @subcommand.setter
    def subcommand(self, subcommand):
        """Sets the subcommand of this Audit.


        :param subcommand: The subcommand of this Audit.  # noqa: E501
        :type: str
        """

        self._subcommand = subcommand

    @property
    def time(self):
        """Gets the time of this Audit.  # noqa: E501


        :return: The time of this Audit.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Audit.


        :param time: The time of this Audit.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def user(self):
        """Gets the user of this Audit.  # noqa: E501


        :return: The user of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Audit.


        :param user: The user of this Audit.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def user_agent(self):
        """Gets the user_agent of this Audit.  # noqa: E501


        :return: The user_agent of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this Audit.


        :param user_agent: The user_agent of this Audit.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    @property
    def user_interface(self):
        """Gets the user_interface of this Audit.  # noqa: E501

        The user interface through which the user session event was performed. Valid values are `CLI`, `GUI`, and `REST`.  # noqa: E501

        :return: The user_interface of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._user_interface

    @user_interface.setter
    def user_interface(self, user_interface):
        """Sets the user_interface of this Audit.

        The user interface through which the user session event was performed. Valid values are `CLI`, `GUI`, and `REST`.  # noqa: E501

        :param user_interface: The user_interface of this Audit.  # noqa: E501
        :type: str
        """

        self._user_interface = user_interface

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Audit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Audit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
